@@ -16,14 +16,14 @@ pretty10exp <- function(x, drop.1 = FALSE, sub10 = FALSE,
     ## ----------------------------------------------------------------------
     ## Arguments: x: numeric vector (e.g. axis tick locations)
     ## ----------------------------------------------------------------------
-    ## Author: Martin Maechler, Date: 7 May 2004; 24 Jan 2006
+    ## Author: Martin Maechler, Date: 7 May 2004, Jan 2006, ...
 
     if(!missing(digits.fuzz)) {
 	message("'digits.fuzz' is deprecated; use 'digits' instead")
 	digits <- digits.fuzz
     }
     lab.type <- match.arg(lab.type)
-    lab.sep <- match.arg(lab.sep)
+    lab.sep  <- match.arg(lab.sep)
 
     l10x <- log10(abs(x))
     eT <- floor(l10x + off) # x == 0 case is dealt with below
@@ -33,14 +33,16 @@ pretty10exp <- function(x, drop.1 = FALSE, sub10 = FALSE,
     if(sub.10 <- !isFALSE(sub10)) {
 	sub10 <- if(isTRUE(sub10))
                      c(0L,0L)
-                 else if(identical(sub10, "10"))
-                     0:1
+                 else if(identical(sub10,  "10")) c(-1L,1L)
+                 else if(identical(sub10, "100")) c(-1L,2L)
+                 else if(identical(sub10,"1000")) c(-2L,3L)
                  else
                      as.integer(sub10)
 	noE <-
 	    if(length(sub10) == 1) {
-		if(sub10 < 0)
-		    stop("'sub10' must not be negative if a single number")
+                ## *Not* really sensible -- was active till 2025-07-26 [sfsmisc version <= 1.1-21]
+		## if(sub10 < 0)
+		##     stop("'sub10' must not be negative if a single number")
 		eT <= sub10
 	    } else if(length(sub10) == 2) {
 		stopifnot(sub10[1] <= sub10[2])
@@ -139,6 +141,12 @@ eaxis <- function(side, at = if(log) axTicks(side, axp=axp, log=log, nintLog=nin
                   else TRUE
     else if(length(labels) == 1 && is.na(labels)) # no 'plotmath'
 	labels <- TRUE
+    if(getOption("digits") > 16 &&
+       (isTRUE(labels) || (is.expression(labels) && "numeric" %in% vapply(labels, mode, "")))) {
+        ## options(digits = 17) leads to ugly decimal formatting
+        op <- options(digits = 15); on.exit(options(op))
+        message("temporarily lower \"digits\" option to 15 ..")
+    }
     axis(side, at = at, labels = labels, las=las, ...)
     if(log) {
 	if(any(at <= 0)) stop("invalid 'log=TRUE' for at <= 0: not a true log scale plot?")
